@@ -27,6 +27,8 @@
 #'
 #' @export
 #'
+#' @importFrom grDevices adjustcolor
+#'
 #' @examples
 #'
 #' # Load reflectance data
@@ -48,9 +50,6 @@
 
 aggplot <- function(rspecdata, by = NULL, FUN.center = mean, FUN.error = sd,
                     lcol = NULL, shadecol = NULL, alpha = 0.2, legend = FALSE, ...) {
-  if (isTRUE(by == 1)) {
-    stop("Cannot group single spectra (use plot instead)")
-  }
 
   # take aggregated data
   cntplotspecs <- aggspec(rspecdata, by = by, FUN = FUN.center)
@@ -151,7 +150,7 @@ aggplot <- function(rspecdata, by = NULL, FUN.center = mean, FUN.error = sd,
     lcol <- col_list
   }
 
-  shadecol <- rgb(t(col2rgb(shadecol)) / 255, alpha = alpha)
+  shadecol <- adjustcolor(shadecol, alpha.f = alpha)
 
   # plot polygons first...
 
@@ -164,44 +163,29 @@ aggplot <- function(rspecdata, by = NULL, FUN.center = mean, FUN.error = sd,
 
   arg$type <- NULL
   arg$x <- polygon_wl
-  arg$y <- polygon_data[, 1]
-  arg$col <- shadecol[1]
   arg$border <- NA
 
-  arg0 <- arg[names(arg) %in% names(formals(polygon))]
-  do.call(polygon, arg0)
-
-  if (ncol(cntplotspecs) > 1) {
-    for (i in 2:ncol(cntplotspecs)) {
-      arg$col <- shadecol[i]
-      arg$y <- polygon_data[, i]
-      arg0 <- arg[names(arg) %in% c(names(formals(polygon)), names(par()))]
-      do.call(polygon, arg0)
-    }
+  for (i in seq_along(cntplotspecs)) {
+    arg$col <- shadecol[i]
+    arg$y <- polygon_data[, i]
+    arg0 <- arg[names(arg) %in% c(names(formals(polygon)), names(par()))]
+    do.call(polygon, arg0)
   }
 
   # ...then lines (so they are on top)
   arg$border <- NULL
-  arg$col <- lcol[1]
   arg$x <- wl
-  arg$y <- cntplotspecs[, 1]
   arg$type <- "l"
-  arg$lty <- lty[1]
-  arg$lwd <- lwd[1]
 
-  arg0 <- arg[names(arg) %in% c(names(formals(plot.default)), names(par()))]
-  do.call(lines, arg0)
-
-  if (ncol(cntplotspecs) > 1) {
-    for (i in 2:ncol(cntplotspecs)) {
-      arg$y <- cntplotspecs[, i]
-      arg$col <- lcol[i]
-      arg$lty <- lty[i]
-      arg$lwd <- lwd[i]
-      arg0 <- arg[names(arg) %in% c(names(formals(plot.default)), names(par()))]
-      do.call(lines, arg0)
-    }
+  for (i in seq_along(cntplotspecs)) {
+    arg$y <- cntplotspecs[, i]
+    arg$col <- lcol[i]
+    arg$lty <- lty[i]
+    arg$lwd <- lwd[i]
+    arg0 <- arg[names(arg) %in% c(names(formals(plot.default)), names(par()))]
+    do.call(lines, arg0)
   }
+
   if (legend) {
     legend("topleft",
       bty = "n", legend = names(cntplotspecs),
