@@ -2,25 +2,27 @@
 #'
 #' Plot a CIE (XYZ, LAB, or LCH) chromaticity diagram.
 #'
-#' @param ciedata (required). a data frame, possibly a result from the [colspace()]
-#' or [cie()] function, containing values for 'x', 'y' and 'z'  coordinates for the CIEXYZ
-#' model, or LAB coordinates for the CIELAB (or CIELCh models), as columns (labeled as such).
-#' @param mono should the monochromatic loci (the 'horseshoe') be
-#'    plotted when `space = "ciexyz"`? Defaults to `TRUE`.
-#' @param theta angle to rotate the plot in the xy plane  when `space = "cielab"`
-#' (defaults to 10).
+#' @param ciedata (required). a data frame, possibly a result from the
+#'   [colspace()] or [cie()] function, containing values for 'x', 'y' and 'z'
+#'   coordinates for the CIEXYZ model, or LAB coordinates for the CIELAB (or
+#'   CIELCh models), as columns (labeled as such).
+#' @param mono should the monochromatic loci (the 'horseshoe') be plotted when
+#'   `space = "ciexyz"`? Defaults to `TRUE`.
+#' @param theta angle to rotate the plot in the xy plane  when
+#'   `space = "cielab"` (defaults to 10).
 #' @param phi angle to rotate the plot in the yz plane  when `space = "cielab"`
-#' (defaults to 45).
+#'   (defaults to 45).
 #' @param r the distance of the eyepoint from the center of the plotting box
-#' when `space = "cielab"`. Very high values approximate an orthographic projection
-#' (defaults to 1e6). See [graphics::persp()] for details.
-#' @param zoom zooms in (values greater than 1) or out (values between 0 and 1) from the plotting area
-#' when `space = "cielab"`.
-#' @param box logical. Should the plot area box and axes be plotted? (defaults to `FALSE`)
-#' @param margin vector of four numbers specifying drawing margins for CIELAB plot
-#'   (defaults to c(0,0,0,0))
+#'   when `space = "cielab"`. Very high values approximate an orthographic
+#'   projection (defaults to 1e6). See [graphics::persp()] for details.
+#' @param zoom zooms in (values greater than 1) or out (values between 0 and 1)
+#'   from the plotting area when `space = "cielab"`.
+#' @param box logical. Should the plot area box and axes be plotted? (defaults
+#'   to `FALSE`)
+#' @param margin vector of four numbers specifying drawing margins for CIELAB
+#'   plot (defaults to c(0,0,0,0))
 #' @param ciebg should the colour background be plotted for CIEXYZ plot?
-#' (defaults to \code{TRUE})
+#'   (defaults to `TRUE`)
 #' @inheritParams triplot
 #'
 #' @examples
@@ -63,6 +65,9 @@ cieplot <- function(ciedata, mono = TRUE, out.lwd = NULL, out.lcol = "black",
     if (is.null(arg$xaxp)) {
       arg$xaxp <- c(0, 0.9, 9)
     }
+    if (is.null(arg$asp)) {
+      arg$asp <- 1
+    }
     if (is.null(arg$yaxp)) {
       arg$yaxp <- c(0, 0.8, 8)
     }
@@ -124,6 +129,8 @@ cieplot <- function(ciedata, mono = TRUE, out.lwd = NULL, out.lcol = "black",
       "ann", "axes", "frame.plot", "panel.first", "panel.last", "asp"
     )] <- NULL
     do.call(points, arg)
+
+    invisible(NULL)
   }
 
   # CIELAB or CIELch
