@@ -30,6 +30,8 @@
 #'
 #' @export
 #'
+#' @importFrom geometry bary2cart
+#'
 #' @keywords internal
 #'
 #' @references Stoddard, M. C., & Prum, R. O. (2008). Evolution of avian plumage
@@ -51,6 +53,7 @@ tcspace <- function(vismodeldata) {
 
     if (attr(dat, "conenumb") > 4) {
       warning("vismodel input is not tetrachromatic, considering first four receptors only", call. = FALSE)
+      attr(vismodeldata, "data.maxqcatches") <- attr(vismodeldata, "data.maxqcatches")[, seq_len(4)]
     }
 
     # check if relative
@@ -69,19 +72,29 @@ tcspace <- function(vismodeldata) {
       stop("Input data is not a ", dQuote("vismodel"), " object and has fewer than four columns", call. = FALSE)
     }
     if (ncol(dat) == 4) {
-      warning("Input data is not a ", dQuote("vismodel"), " object; treating columns as unstandardized quantum catch for ", dQuote("u"), ", ", dQuote("s"), ", ", dQuote("m"), ", and ", dQuote("l"), " receptors, respectively", call. = FALSE)
+      if (!all(c("u", "s", "m", "l") %in% names(dat))) {
+        message("Input data is not a ", dQuote("vismodel"), " object; treating columns as unstandardized quantum catch for ", dQuote("u"), ", ", dQuote("s"), ", ", dQuote("m"), ", and ", dQuote("l"), " receptors, respectively", call. = FALSE)
+      }
     }
 
     if (ncol(dat) > 4) {
-      warning("Input data is not a ", dQuote("vismodel"), " object *and* has more than four columns; treating the first four columns as unstandardized quantum catch for ", dQuote("u"), ", ", dQuote("s"), ", ", dQuote("m"), ", and ", dQuote("l"), " receptors, respectively", call. = FALSE)
+      if (all(c("u", "s", "m", "l") %in% names(dat))) {
+        dat <- dat[, c("u", "s", "m", "l")]
+      } else {
+        message("Input data is not a ", dQuote("vismodel"), " object and has more than four columns; treating the first four columns as unstandardized quantum catch for ", dQuote("u"), ", ", dQuote("s"), ", ", dQuote("m"), ", and ", dQuote("l"), " receptors, respectively", call. = FALSE)
+      }
+      attr(vismodeldata, "data.maxqcatches") <- attr(vismodeldata, "data.maxqcatches")[, seq_len(4)]
     }
 
     dat <- dat[, seq_len(4)]
     names(dat) <- c("u", "s", "m", "l")
 
-    dat <- dat / rowSums(dat)
-    warning("Quantum catch have been transformed to be relative (sum of 1)", call. = FALSE)
-    attr(vismodeldata, "relative") <- TRUE
+    # Transform to relative if necessary
+    if (!isTRUE(all.equal(rowSums(dat), rowSums(dat / rowSums(dat)), tol = 0.001))) {
+      dat <- dat / rowSums(dat)
+      message("Quantum catch have been transformed to be relative (sum of 1)")
+      attr(vismodeldata, "relative") <- TRUE
+    }
   }
 
   if (all(c("u", "s", "m", "l") %in% names(dat))) {
@@ -101,11 +114,17 @@ tcspace <- function(vismodeldata) {
     l <- dat[, 4]
   }
 
+  ref <- matrix(c(0, 0, 3/4,
+                  -sqrt(6)/4, -sqrt(2)/4, -1/4,
+                  0, 1/sqrt(2), -1/4,
+                  sqrt(6)/4, -sqrt(2)/4, -1/4), nrow = 4, ncol = 3, byrow = TRUE)
   # cartesian coordinates
 
-  x <- ((1 - 2 * s - m - u) / 2) * sqrt(3 / 2)
-  y <- (-1 + 3 * m + u) / (2 * sqrt(2))
-  z <- u - (1 / 4)
+  coords <- bary2cart(ref, cbind(u, s, m, l))
+
+  x <- coords[, 1]
+  y <- coords[, 2]
+  z <- coords[, 3]
 
   # vertex cartesian coordinates & their spherical data
 
@@ -172,5 +191,13 @@ tcspace <- function(vismodeldata) {
   attr(res, "data.visualsystem.achromatic") <- attr(vismodeldata, "data.visualsystem.achromatic")
   attr(res, "data.background") <- attr(vismodeldata, "data.background")
 
+  maxqcatches <- attr(vismodeldata, "data.maxqcatches")
+  if (!is.null(maxqcatches) && ncol(maxqcatches)==4) {
+    maxqcatches <- maxqcatches / rowSums(maxqcatches)
+    attr(res, "data.maxgamut") <- bary2cart(ref, maxqcatches)
+  } else {
+    attr(res, "data.maxgamut") <- NA
+  }
+
   res
 }
