@@ -20,12 +20,14 @@ test_that("Warnings", {
   expect_warning(vismodel(flowers, visual = "bluetit", achromatic = test_rspec), "achromatic is an rspec")
   expect_warning(vismodel(flowers, visual = "bluetit", achromatic = test_matrix), "achromatic is a matrix")
   expect_silent(vismodel(flowers, visual = "bluetit", achromatic = FALSE))
-})
 
-test_that("Summary", {
-  data(sicalis)
-  vis.sicalis <- vismodel(sicalis, visual = "avg.uv")
-  summary(vis.sicalis)
+  expect_error(vismodel(flowers, vonkries = TRUE, bkg = NULL), "background is NULL")
+  expect_error(vismodel(flowers, trans = NULL), "transmission is NULL")
+
+  flowers_NIR <- expect_warning(as.rspec(flowers, lim = c(300, 1200)), "Interpolating beyond")
+
+  expect_error(vismodel(flowers_NIR), "wavelength range")
+  expect_error(vismodel(flowers_NIR, sensmodel(c(350, 450, 550, 650))), "wavelength range")
 })
 
 test_that("Sensmodel", {
